from .utl import *
from ._http import *


# TODO
@traxa_rpc
def web3_clientVersion(**kwargs):
    params = []
    return params


# TODO
@traxa_rpc
def web3_sha3(data, **kwargs):
    params = [data]
    return params