from .utl import *
from ._http import *


@traxa_rpc
def net_version(**kwargs):
    params = []
    return params


@traxa_rpc
def net_peerCount(**kwargs):
    params = []
    return params


@traxa_rpc
def net_listening(**kwargs):
    params = []
    return params